@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007, 2008, 2009 David Shaw <dshaw@jabberwocky.com>
+ * Copyright (C) 2007, 2008, 2009, 2012 David Shaw <dshaw@jabberwocky.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
-static const char RCSID[]="$Id: paperkey.c 601 2009-10-14 19:58:10Z dshaw $";
 
 #include <config.h>
 #include <stdio.h>
@@ -129,7 +128,7 @@ main(int argc,char *argv[])
 
       case OPT_VERSION:
       case 'V':
-	printf("%s\n",PACKAGE_STRING);
+	printf("%s (%s)\n",PACKAGE_STRING,HOST_OS);
 	printf("%s\n",COPYRIGHT_STRING);
 	printf("This is free software.  You may redistribute copies of it"
 	       " under the terms of\n");
